parsers/
========

`View code on Github <https://github.com/activist-org/ts-backend-check/tree/main/src/ts_backend_check/parsers>`_

.. toctree::
    :maxdepth: 1

    django_parser
    typescript_parser
